/*
	Sangstrm.H - Streaming Device Driver (S508/S514) User Interface Header
	Copyright (c) 2001 Sangoma Technologies Inc.
	v2.00 September 2002

	Set tabs to 4 spaces when viewing.
*/

//
// DeviceIoControl command codes. Must include "winioctl.h" in app for
// definition of CTL_CODE and defines.
//

// Standard CBLOCK-passing command:
// Input: ptr to CHDLC_MAILBOX_STRUCT structure
// Output: ptr to CHDLC_MAILBOX_STRUCT structure (may be same as input)
// Uses Buffered I/O. Synchronous call.
#define IoctlCodeCblockCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 10, METHOD_BUFFERED, FILE_ANY_ACCESS)

// Command to send a frame:
// Input: ptr to CHDLC_MAILBOX_STRUCT structure
// Output: ptr to CHDLC_MAILBOX_STRUCT structure (may be same as input)
// Uses Direct I/O (Irp->MdlAddress). Synchronous call.
// Note: Frame only queued for transmission when ReturnCode is 0x00. If not,
//       must repeat this command with reinitialized structure.
//       The Command member need not be initialized.
#define IoctlCodeWriteCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 11, METHOD_OUT_DIRECT, FILE_ANY_ACCESS)

// Command to read a frame:
// Input: NULL
// Output: ptr to STREAMING_READ_INFO (plus adequate data storage area)
// Uses Direct I/O (Irp->MdlAddress). Blocking call on device handle.
// Note: Since this command blocks all further I/O requests, it must be done
//       on a separate device handle. Just open the same device again and use
//       this handle for reading.
#define IoctlCodeReadCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 12, METHOD_IN_DIRECT, FILE_ANY_ACCESS)

// Command to retrieve status information:
// Input: NULL
// Output: ptr to CHDLC_DATA_TX_STATUS_EL_STRUCT structure
// Uses Buffered I/O. Synchronous call.
#define IoctlCodeStatusCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 13, METHOD_BUFFERED, FILE_ANY_ACCESS)

// Command to configure the driver:
// Input: ptr to DRV_CONFIG_INFO struct
// Output: ptr to DRV_CONFIG_INFO structure
// Uses Buffered I/O. Synchronous call.
#define IoctlDriverConfigCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 14, METHOD_BUFFERED, FILE_ANY_ACCESS)

// Command to get devices available for use.
// This command is used only by Configurator.exe.
// Input: NULL
// Output: ptr to SANGSTRM_DEVICE structure
// Uses Buffered I/O. Synchronous call. Used by
// configurator program only.
#define IoctlGetDevicesCommand	CTL_CODE(FILE_DEVICE_UNKNOWN, 15, METHOD_BUFFERED, FILE_ANY_ACCESS)


/* Buffered and unbuffered mode definitions */
#define NUMBER_OF_CRC_BYTES			2

/*Buffered mode only definitions*/
#define SIZEOF_RX_BFR_LGTH_IND		4  /* sizeof RX buffer length indicator, actually sizeof(ULONG) */
#define NO_DRVR_RX_BFRS				4  /* number of RX buffers allocated */

/* return codes from IoctlDriverConfigCommand command */
#define COMMAND_PERFORMED_SUCCESSFULLY      0x00		
#define BUFFER_ALLOCATION_FAILED            0x01 /* system can't allocate buffer of required size */
#define DO_SET_CHDLC_CONFIGURATION      	0x02 /* SET_CHDLC_CONFIGURATION or SET_ASY_CONFIGURATION must be done
													before using this command */ 
#define DO_DISABLE_CHDLC_COMMUNICATIONS		0x03 /* use DISABLE_CHDLC_COMMUNICATIONS or DISABLE_ASY_COMMUNICATIONS
													before reconfiguring the driver */
#define INVALID_TOTAL_RX_BUFFER_SIZE		0x04 /* SIZEOF_RX_BFR_LGTH_IND(4 bytes) + 
													CHDLC_DATA_RX_STATUS_EL_STRUCT(16 bytes)+
												    max_CHDLC_data_field_length(set with SET_CHDLC_CONFIGURATION command)+
												    NUMBER_OF_CRC_BYTES(2 bytes) won't fit in to total RX buffer size, 
													requested by the user, devided by NO_DRVR_RX_BFRS (4) .
												 */
#define BUFF_MODE_SET_INTERRUPT_TRIGS_FAILED 0x05 /* SET_CHDLC_INTERRUPT_TRIGGERS command failed */				
//
// Driver-defined return codes for CBLOCK-associated commands.
//
#define RCODE_TIMEOUT_ERROR		0x7f	// Card is not responding to command.
#define RCODE_INIT_ERROR		0x7e	// Card could not be initialized.
										// (SET_CHDLC_CONFIGURATION only)

//
// All structures below must be packed on 1-byte boundaries.
//

#pragma pack(1)

//
// Possible values for Status member of STREAMING_READ_INFO structure
// when IoctlCodeReadCommand returns.
//
#define RX_DATA_AVAILABLE	0x01	//Data was read.
#define RX_DATA_TIMEOUT		0x03	//Notification that no data was received in the
									//last 5 seconds.

//
// Equivalent to Receive Status Element in Manual.
// Data of variable length follows.
//
typedef struct _STREAMING_READ_INFO {
	UCHAR Status;					// set to 0x01 on return if frame read
	USHORT FrameLength;				// set to length of frame that follows
	UCHAR MiscBits;					// various frame-related bits
	USHORT TimeStamp;				// timestamp of frame
	UCHAR Reserved[10];
	UCHAR Data[1];					// variable-length frame data
} STREAMING_READ_INFO, *PSTREAMING_READ_INFO;

//Driver configuration struct
typedef struct {
	USHORT return_code;
	ULONG buffer_size;
}DRV_CONFIG_INFO;

typedef struct{
	USHORT CardType;
	
	ULONG  BusNumber;
	ULONG  SlotNumber;
	USHORT CPU;
	USHORT comms_port;
	
	ULONG  Memory;
	ULONG  IRQ;
	ULONG  IO_Port;

}SANGSTRM_DEVICE;

#pragma pack()
